import React, {useState, useEffect} from "react";

const Appearance = ({fonts}) => {
	const [font, setFont]                     = useState("");
	const [highlightColor, setHighlightColor] = useState("");

	const changeFont = event => {
		const value = event.target.value;
		setFont(value);
		window.appSettings.set("font", value);
	};

	const changeColor = event => {
		const value = event.target.value;
		setHighlightColor(value);
		window.appSettings.set("highlightColor", value);
	};

	useEffect(() => {
		(async setFont => setFont(await window.appSettings.get("font", "Iosevka")))(setFont);
		(async setHighlightColor => setHighlightColor(await window.appSettings.get("highlightColor", "#e6c17b")))(setHighlightColor);
	}, []);

	return (
		<section className="grid">
			<label>Font in slides:</label>
			<select value={font} onChange={changeFont}>
				{fonts.map(font => font.trim().replace(/(^"|"$)/g, "")).map(font => <option key={font} value={font}>{font}</option>)}
			</select>
			<label>Global highlight color:</label>
			<input type="color" value={highlightColor} onChange={changeColor} />
		</section>
	);
};

export default Appearance;